/*
 * The MIT License
 *
 * Copyright 2021 Sebastian Schauer.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package sudoku.model.games;

import sudoku.controller.GameController;
import sudoku.model.board.Area;
import sudoku.model.board.Sudoku;

/**
 * A color sudoku. Works like a regular sudoku, but has additional areas:
 * The corresponding cells of each subsquare form a new areas (e.g. all
 * center cells or all up left cells.)
 * 
 * @author Sebastian Schauer
 */
public class ColorSudoku extends RegularSudoku {

    public ColorSudoku(int size, GameController gc) {
        super(size, gc);
        name = "Farbsudoku";
        type = GameType.Color;
        for (int i = 0; i < size; i++) {
            Area a = new Area(size, true);
            int xoff = i % root;
            int yoff = i / root;
            for (int jx = 0; jx < size; jx += root) {
                for (int jy = 0; jy < size; jy += root) {
                    a.addCell(cells[xoff + jx][yoff + jy]);
                }
            }
        }
        super.foregroundColors = size;
    }
    
    /**
     * Copies this sudoku.
     * @return The copy
     */
    @Override
    public Sudoku copy() {
        return super.copy(new ColorSudoku(size, myGC));
    }
}
